@@ -1,4 +1,10 @@
+.dparserLoad <- function() {
+  .Call(`_nonmem2rx_iniDparserPtr`,
+        dparser::.dparsePtr(),
+        PACKAGE = "nonmem2rx")
+}
 .onLoad <- function(libname, pkgname) {
+  .dparserLoad()
   .Call(`_nonmem2rx_r_parseIni`)
   if (requireNamespace("nlme", quietly=TRUE)) {
     rxode2::.s3register("nlme::getData", "nonmem2rx")
@@ -8,6 +14,7 @@
   .rxUiGetRegister()
   rxode2::.s3register("rxode2::rxUiGet", "simulationModelIwres")
 }
-.onAttach <- function(libname,pkgname){
+.onAttach <- function(libname,pkgname) {
+  .dparserLoad()
   .Call(`_nonmem2rx_r_parseIni`)
 }
